@@ -339,7 +339,9 @@ sub print(;$)
 	$self->head->print($out);
 	my $body = $self->body;
 	$body->print($out) if $body;
-	$body->endsOnNewline or $out->print("\n");
+
+	# We need a new-line at the end of a full message.
+	ref $self ne __PACKAGE__ or $body->endsOnNewline or $out->print("\n");
 	$self;
 }
 
