@@ -4,11 +4,13 @@
 #oodist: testing, however the code of this development version may be broken!
 
 package Mail::Message::Field::Date;
-use base 'Mail::Message::Field::Structured';
+use parent 'Mail::Message::Field::Structured';
 
 use warnings;
 use strict;
 
+use Log::Report   'mail-message', import => [ qw/__x error/ ];
+
 use POSIX qw/mktime tzset/;
 
 #--------------------
@@ -44,10 +46,9 @@ form.
 my $dayname = qr/Mon|Tue|Wed|Thu|Fri|Sat|Sun/;
 my @months  = qw/Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec/;
 my %monthnr; { my $i; $monthnr{$_} = ++$i for @months }
-my %tz      = qw/
-	EDT -0400  EST -0500  CDT -0500  CST -0600
-	MDT -0600  MST -0700  PDT -0700  PST -0800
-	UT  +0000  GMT +0000/;
+my %tz      = qw/EDT -0400  EST -0500  CDT -0500  CST -0600
+				MDT -0600  MST -0700  PDT -0700  PST -0800
+				UT  +0000  GMT +0000/;
 
 sub parse($)
 {	my ($self, $string) = @_;
@@ -59,11 +60,11 @@ sub parse($)
 			( [A-Z][a-z][a-z]|[0-9][0-9]  ) \s+  # month
 			( (?: 19 | 20 | ) [0-9][0-9]  ) \s+  # year
 			( [0-1]?[0-9] | 2[0-3] )        \s*  # hour
-			    [:.] ( [0-5][0-9] )         \s*  # minute
+				[:.] ( [0-5][0-9] )         \s*  # minute
 			(?: [:.] ( [0-5][0-9] ) )?      \s*  # second (optional)
 			( [+-][0-9]{4} | [A-Z]+ )?           # zone
-			                                     # optionally followed by trash
-		/x or return undef;
+			\s*
+		$ /x or return undef;
 
 	$dn //= '';
 	$dn   =~ s/\s+//g;
@@ -90,16 +91,14 @@ sub date() { $_[0]->{MMFD_date} }
 =method addAttribute ...
 Attributes are not supported for date fields.
 
-=error No attributes for date fields.
+=error no attributes for date fields.
 It is not possible to add attributes to date fields: it is not permitted
 by the RFCs.
-
 =cut
 
 sub addAttribute($;@)
 {	my $self = shift;
-	$self->log(ERROR => 'No attributes for date fields.');
-	$self;
+	error __x"no attributes for date fields.";
 }
 
 =method time
